@@ -3,9 +3,10 @@
 import logging
 import threading
 
+from python2sky.context.IgnoredTracerContext import IgnoredTracerContext
 from python2sky import config
 from python2sky.config import OPERATION_NAME_THRESHOLD
-from python2sky.context.trace_context import IgnoredTracerContext, TracingContext
+from python2sky.context.trace_context import TracingContext
 from python2sky.exception.exceptions import SkywalkingException
 from python2sky.util import string_util
 from python2sky.util.common import null_value
